#!/usr/bin/env python

import sys
from os.path            import exists

from crebs.files        import create_image_list, check_file_options, make_needed_dirs
from crebs.debug        import report, report_options
from crebs.slideshows   import create_slideshow_xml, write_slideshow, get_slideshow_name
from crebs.wallpapers   import register_wallpaper
from crebs.conf         import set_wallpaper
from crebs.notify       import send_notification


def cli_warn_file_overwrite(s_filename):
    """Warns that a file with the same name already exists."""

    # FUTURE: prompt user

    sys.stderr.write(_("Error: File already exists: {0}\n").format(s_filename))

    return False


def cli(files, options):
    """Makes a slideshow without using the GUI."""

    # Set up data
    image_list = create_image_list(files, options)

    # FUTURE: Ask user for any extra info

    # Check options
    options = check_file_options(options)
    if len(image_list) < 2 and options.set_wallpaper:
        options.set_wallpaper = False
        report(4, 'Options: set wallpaper implicitly unset by fewer than 2 images')

    # Debugging information
    report_options(5, options, files, image_list)

    # Create slideshow
    s_xml = create_slideshow_xml(image_list, options.name)

    # Print to standard output
    if options.standard_output or options.verbosity >= 5:
        print s_xml

    # Check for overwrite
    if options.file_creation:

        if exists(options.output) and not options.force_overwrite:
            ok_to_write = cli_warn_file_overwrite(options.output)
        else:
            ok_to_write = True

        # Write slideshow
        if ok_to_write:
            make_needed_dirs(options.output)

            slideshow_written = write_slideshow(options.output, s_xml)

            # Register wallpaper
            if slideshow_written and options.set_wallpaper:
                s_name = get_slideshow_name(options)

                register_wallpaper(s_name, options.output)

                # Set wallpaper
                wallpaper_set = set_wallpaper(options.output)

                # Send notification
                if wallpaper_set and options.notify:
                    send_notification(s_name)

