#!/usr/bin/env python

import os
from os.path            import basename, join, dirname, exists

from crebs.debug        import report
from crebs.slideshows   import is_slideshow_file, import_slideshow


def create_image_list(files, options, indent_offset = 0):
    """Creates the image list from command line arguments."""

    report(2, _("Creating the image list..."), indent_offset)

    image_list = []

    for i in range(len(files)):
        if is_slideshow_file(files[i], True, 2):
            slides = import_slideshow(files[i], 2)

            for slide in slides:
                image_list.append(slide)

        else:
            if not options.gui:
                report(2, _("Adding an image..."), indent_offset + 1)
                report(2, files[i], indent_offset + 2)

            if options.specific_durations[i] < 0:
                duration = options.default_duration
            else:
                duration = options.specific_durations[i]

            if options.specific_transitions[i] < 0:
                transition = options.default_transition
            else:
                transition = options.specific_transitions[i]

            report(3, "Duration: {0}. Transition: {1}.".format(duration, transition), indent_offset + 2)

            image_list.append((files[i], duration, transition))

        report(3, "Success.", indent_offset + 1.5)

    report(3, "Success.", indent_offset + 0.5)

    return image_list


def safe_filename(s_name):
    """Turns the slideshow's name into a filesystem-safe name."""

    report(3, "Ensuring the name is filesystem-safe...", 1)

    safe_name = s_name
    safe_name = safe_name.replace(' ','_').replace("'",'_').replace('"', '_').replace('?','_')
    safe_name = safe_name.replace('[','_').replace(']','_').replace('/','_').replace('\\','_')
    safe_name = safe_name.replace('=','_').replace('+','_').replace('<','_').replace('>','_')
    safe_name = safe_name.replace(':','_').replace(';','_').replace(',','_').replace('*','_')
    safe_name = safe_name.replace('%','_')

    safe_name += '.xml'

    report(3, "Success." + " ({0})".format(safe_name), 1.5)

    return safe_name


def check_file_options(options):
    """Checks the file options and fills in any details."""

    report(3, "Checking the file options...")

    if options.output:
        options.filename = basename(options.output)

    else:
        if options.filename:
            options.output = join(options.directory, options.filename)

        elif options.name:
            options.filename = safe_filename(options.name)
            options.output = join(options.directory, options.filename)

        else:
            options.file_creation = False
            report(3, "Not enough information to write slideshow file.", 1)

    report(3, "Success.", 0.5)

    return options


def make_needed_dirs(filename):
    """Makes any needed directories for the slideshow file."""

    s_dir = dirname(filename)
    if not exists(s_dir):
        os.makedirs(s_dir)

