#!/bin/bash

usage()
{
    cat << EOF
Usage: $0 [[-h]|[-p INSTALLATION_DIRECTORY]? [-v]*]

This script will install Create Background Slideshow, a wallpaper slideshow 
creator for the GNOME desktop, to /usr/local by default, or to the directory 
passed with the -p flag.

OPTIONS:
  -h    Shows this message
  -p    Specifies installation directory
  -v    Be more verbose (use -v -v for extra verbosity)
EOF
}

PREFIX=/usr/local
VERBOSE=

while getopts "hp:v" OPTION
do
    case $OPTION in
        h)
            usage
            exit 1
            ;;
        p)
            PREFIX=$OPTARG
            ;;
        v)
            VERBOSE=$VERBOSE+1
            ;;
        ?)
            usage
            exit
            ;;
    esac
done

if [[ $VERBOSE -ge 1 ]]
then
    echo "Creating required directories..."
fi

# Create directories if they don't already exist
for DIR in bin share share/applications share/man share/man/man1 share/crebs share/crebs/glade share/crebs/lib share/crebs/lib/crebs share/crebs/locale share/crebs/locale/cy share/crebs/locale/de share/crebs/locale/en_GB share/crebs/locale/it share/crebs/locale/lt share/crebs/locale/ro share/crebs/locale/ru share/crebs/locale/uk share/crebs/locale/cy/LC_MESSAGES share/crebs/locale/de/LC_MESSAGES share/crebs/locale/en_GB/LC_MESSAGES share/crebs/locale/it/LC_MESSAGES share/crebs/locale/lt/LC_MESSAGES share/crebs/locale/ro/LC_MESSAGES share/crebs/locale/ru/LC_MESSAGES share/crebs/locale/uk/LC_MESSAGES
do
    if [[ ! -d $PREFIX/$DIR ]]
    then
        if [[ $VERBOSE -ge 2 ]]
        then
            echo "    $PREFIX/$DIR..."
        fi
        mkdir $PREFIX/$DIR
    fi
done

if [[ $VERBOSE -ge 1 ]]
then
    echo "Copying files..."
fi

# Copy the files
for DIR in bin share/applications share/man/man1 share/crebs/glade share/crebs/lib/crebs share/crebs/locale/cy/LC_MESSAGES share/crebs/locale/de/LC_MESSAGES share/crebs/locale/en_GB/LC_MESSAGES share/crebs/locale/it/LC_MESSAGES share/crebs/locale/lt/LC_MESSAGES share/crebs/locale/ro/LC_MESSAGES share/crebs/locale/ru/LC_MESSAGES share/crebs/locale/uk/LC_MESSAGES
do
    if [[ $VERBOSE -ge 2 ]]
    then
        echo "    $DIR/*..."
    fi
    cp crebs/$DIR/* $PREFIX/$DIR/
done

if [[ $VERBOSE -ge 1 ]]
then
    echo "Updating desktop database..."
fi

# Register CreBS as an application for its MIME types
update-desktop-database

if [[ $VERBOSE -ge 1 ]]
then
    echo "Finished."
fi
